@@ -44,6 +44,7 @@
 extern SourceReader	gReader;
 extern int gMaxNameSize;
 extern bool gPatternEvalMode;
+extern bool	gSimpleNames;
 
 // History
 // 23/05/2005 : New environment management
@@ -340,7 +341,7 @@ static Tree realeval (Tree exp, Tree visited, Tree localValEnv)
 			isBoxPrim0(exp) || isBoxPrim1(exp) || 
 			isBoxPrim2(exp) || isBoxPrim3(exp) || 
 			isBoxPrim4(exp) || isBoxPrim5(exp) ||
-			isBoxFFun(exp) || isBoxFConst(exp) ) {
+			isBoxFFun(exp) || isBoxFConst(exp) || isBoxFVar(exp) ) {
 		return exp;
 
 	// block-diagram constructors
@@ -710,15 +711,24 @@ static int eval2int (Tree exp, Tree visited, Tree localValEnv)
 	}
 }
 
-static bool isIdentChar(char c)
+static bool isDigitChar(char c)
 {
-	return ((c >= 'a') & (c <= 'z')) || ((c >= 'A') & (c <= 'Z')) || ((c >= '0') & (c <= '9')) || (c == '_');
+    return (c >= '0') & (c <= '9');
 }
 
-static char* writeIdentValue(char* dst, const char* ident, Tree visited, Tree localValEnv)
+static bool isIdentChar(char c)
+{
+    return ((c >= 'a') & (c <= 'z')) || ((c >= 'A') & (c <= 'Z')) || ((c >= '0') & (c <= '9')) || (c == '_');
+}
+
+const char* Formats [] = {"%d", "%1d", "%2d", "%3d", "%4d"};
+
+static char* writeIdentValue(char* dst, int format, const char* ident, Tree visited, Tree localValEnv)
 {
 	int n = eval2int(boxIdent(ident), visited, localValEnv);
-	return dst + sprintf(dst, "%d", n);
+    int i = min(4,max(format,0));
+    
+	return dst + sprintf(dst, Formats[i], n);
 }
 
 static const char * evalLabel (const char* label, Tree visited, Tree localValEnv)
@@ -731,7 +741,7 @@ static const char * evalLabel (const char* label, Tree visited, Tree localValEnv
 	char*		id  = &ident[0];
 
 	bool		parametric = false;
-	int 		state = 0;
+	int 		state = 0; int format = 0;
 	char		c;
 
 	while ((c=*src++)) {
@@ -743,28 +753,39 @@ static const char * evalLabel (const char* label, Tree visited, Tree localValEnv
 					*dst++ = *src++; 		// copy escape char and skip one char
 				} else {
 					state = 1;				// prepare ident mode
+                    format = 0;
 					parametric = true;
 					id  = &ident[0];
 				}
 			} else {
 				*dst++ = c;					// copy char
 			}
-		} else {
+		} else if (state == 1) {
+            // read the format 
+            if (isDigitChar(c)) {
+                format = format*10 + (c-'0');
+            } else {
+                state = 2;
+                --src; // unread !!!
+            }
+
+        } else {
+            
 			// within ident mode
 			if (isIdentChar(c)) {
 				*id++ = c;
 			} else {
 				*id = 0;
-				dst = writeIdentValue(dst, ident, visited, localValEnv);
+				dst = writeIdentValue(dst, format, ident, visited, localValEnv);
 				state = 0;
 				src -= 1;
 			}
 		}
 	}
 
-	if (state == 1) {
+	if (state == 2) {
 		*id = 0;
-		dst = writeIdentValue(dst, ident, visited, localValEnv);
+		dst = writeIdentValue(dst, format, ident, visited, localValEnv);
 	}
 	*dst = 0;
 	return (parametric) ? strdup(res) : label;
@@ -964,7 +985,7 @@ static Tree applyList (Tree fun, Tree larg)
 
 		Tree	fname;
 		if (getDefNameProperty(fun, fname)) {
-			stringstream s; s << tree2str(fname) << "(" << boxpp(arg) << ")";
+			stringstream s; s << tree2str(fname); if (!gSimpleNames) s << "(" << boxpp(arg) << ")";
 			setDefNameProperty(f, s.str());
 		}
 		return applyList(f, tl(larg));
@@ -1055,7 +1076,10 @@ static void addLayerDef(Tree id, Tree def, Tree lenv)
 		if (def == olddef) {
 			evalwarning(getDefFileProp(id), getDefLineProp(id), "equivalent re-definitions of", id);
 		} else {
-			evalwarning(getDefFileProp(id), getDefLineProp(id), "non-equivalent re-definition of", id);
+            fprintf(stderr, "%s:%d: ERROR: redefinition of symbols are not allowed : ", getDefFileProp(id), getDefLineProp(id)); 
+            print(id,stderr); 
+            fprintf(stderr, " is already defined in file \"%s\" line %d \n", getDefFileProp(id), getDefLineProp(id)); 
+            gErrorCount++;
 		}
 	}
 	setProperty(lenv, id, def);
