@@ -17,7 +17,12 @@ class Log10Prim : public xtended
 	virtual Type 	infereSigType (const vector<Type>& args)
 	{
 		assert (args.size() == arity());
-		return floatCast(args[0]);
+		interval i = args[0]->getInterval();
+		if (i.valid && (i.lo > 0)) {
+			return castInterval(floatCast(args[0]), interval(log10(i.lo), log10(i.hi)));
+		} else {
+			return floatCast(args[0]);
+		}
 	}
 	
 	virtual void 	sigVisit (Tree sig, sigvisitor* visitor) {}	
