@@ -16,7 +16,12 @@ class LogPrim : public xtended
 	virtual Type 	infereSigType (const vector<Type>& args)
 	{
 		assert (args.size() == arity());
-		return floatCast(args[0]);
+		interval i = args[0]->getInterval();
+		if (i.valid & i.lo>0) {
+			return castInterval(floatCast(args[0]), interval(log(i.lo), log(i.hi)));
+		} else {
+			return floatCast(args[0]);
+		}
 	}
 	
 	virtual void 	sigVisit (Tree sig, sigvisitor* visitor) {}	
