@@ -1,7 +1,18 @@
 #include "xtended.hh"
+#include "compatibility.hh"
 #include "Text.hh"
 #include <math.h>
 
+#ifdef WIN32 
+/* missing on Windows : see http://bugs.mysql.com/bug.php?id=15936 */
+inline double rint(double nr)
+{
+    double f = floor(nr);
+    double c = ceil(nr);
+    return (((c -nr) >= (nr - f)) ? f : c);
+}
+#endif
+
 class RintPrim : public xtended
 {
 
@@ -16,7 +27,12 @@ class RintPrim : public xtended
 	virtual Type 	infereSigType (const vector<Type>& args)
 	{
 		assert (args.size() == arity());
-		return floatCast(args[0]);
+		interval i = args[0]->getInterval();
+		if (i.valid) {
+			return castInterval(floatCast(args[0]), interval(rint(i.lo), rint(i.hi)));
+		} else {
+			return floatCast(args[0]);
+		}
 	}
 	
 	virtual void 	sigVisit (Tree sig, sigvisitor* visitor) {}	
