@@ -18,6 +18,7 @@
     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  ************************************************************************
  ************************************************************************/
+#define FAUSTVERSION "0.9.9.4"
 
 #include <stdio.h>
 #include <string.h>
@@ -74,11 +75,7 @@ Tree 			gResult2;
 
 SourceReader	gReader;
 
-list<string>	gNameProperty;
-list<string>	gAuthorProperty;
-list<string>	gCopyrightProperty;
-list<string>	gVersionProperty;
-list<string>	gLicenseProperty;
+map<Tree, set<Tree> > gMetaDataSet;
 
 
 /****************************************************************
@@ -97,6 +94,7 @@ bool            gPrintXMLSwitch = false;
 int            	gBalancedSwitch = 0;
 int            	gFoldThreshold 	= 25;
 int            	gMaxNameSize 	= 40;
+bool			gSimpleNames 	= false;
 bool			gLessTempSwitch = false;
 int				gMaxCopyDelay	= 16;
 
@@ -108,12 +106,12 @@ bool			gPatternEvalMode = false;
 
 //-- command line tools
 
-static bool isCmd(char* cmd, char* kw1)
+static bool isCmd(const char* cmd, const char* kw1)
 {
 	return 	(strcmp(cmd, kw1) == 0);
 }
 
-static bool isCmd(char* cmd, char* kw1, char* kw2)
+static bool isCmd(const char* cmd, const char* kw1, const char* kw2)
 {
 	return 	(strcmp(cmd, kw1) == 0) || (strcmp(cmd, kw2) == 0);
 }
@@ -168,6 +166,10 @@ bool process_cmdline(int argc, char* argv[])
 			gMaxNameSize = atoi(argv[i+1]);
 			i += 2;
 
+		} else if (isCmd(argv[i], "-sn", "--simple-names")) {
+			gSimpleNames = true;
+			i += 1;
+
 		} else if (isCmd(argv[i], "-lb", "--left-balanced")) {
 			gBalancedSwitch = 0;
 			i += 1;
@@ -214,8 +216,8 @@ bool process_cmdline(int argc, char* argv[])
 
 void printversion()
 {
-	cout << "FAUST, DSP to C++ compiler, Version 0.9.9.1\n";
-	cout << "Copyright (C) 2002-2007, GRAME - Centre National de Creation Musicale. All rights reserved. \n\n";
+	cout << "FAUST, DSP to C++ compiler, Version " << FAUSTVERSION << "\n";
+	cout << "Copyright (C) 2002-2008, GRAME - Centre National de Creation Musicale. All rights reserved. \n\n";
 }
 
 
@@ -235,6 +237,7 @@ void printhelp()
 	cout << "-svg \t\tprint block-diagram --svg file\n";
 	cout << "-f <n> \t\t--fold <n> threshold during block-diagram generation (default 25 elements) \n";
 	cout << "-mns <n> \t--max-name-size <n> threshold during block-diagram generation (default 40 char)\n";
+	cout << "-sn \t\tuse --simple-names (without arguments) during block-diagram generation\n";
 	cout << "-xml \t\tgenerate an --xml description file\n";
 	cout << "-lb \t\tgenerate --left-balanced expressions\n";
 	cout << "-mb \t\tgenerate --mid-balanced expressions (default)\n";
@@ -252,6 +255,28 @@ void printhelp()
 }
 
 
+void printheader(ostream& dst)
+{
+    Tree author = tree("author");
+        
+    dst << "//-----------------------------------------------------" << endl;
+    for (map<Tree, set<Tree> >::iterator i = gMetaDataSet.begin(); i != gMetaDataSet.end(); i++) {
+        dst << "// " << *(i->first) << " : ";      
+        if (i->first != author) {
+            dst << **(i->second.begin());
+        } else {
+            for (set<Tree>::iterator j = i->second.begin(); j != i->second.end(); j++) {
+                if (j != i->second.begin()) { dst << endl << "// contributors : "; }
+                dst << **j << " ";
+            }
+        }
+        dst << endl;
+    }
+
+    dst << "//" << endl;
+    dst << "// Code generated with Faust " << FAUSTVERSION << " (http://faust.grame.fr)" << endl;
+    dst << "//-----------------------------------------------------" << endl;
+}
 
 
 
@@ -304,7 +329,8 @@ int main (int argc, char* argv[])
 
 	Tree process = evalprocess(gReader.expandlist(gResult2));
 	if (gErrorCount > 0) {
-		cerr << "Total of " << gErrorCount << " errors during evaluation of : process = " << boxpp(process) << ";\n";
+       // cerr << "Total of " << gErrorCount << " errors during evaluation of : process = " << boxpp(process) << ";\n";
+        cerr << "Total of " << gErrorCount << " errors during the compilation of  " << masterFilename << ";\n";
 		exit(1);
 	}
 
@@ -350,18 +376,15 @@ int main (int argc, char* argv[])
 	 6 - generate XML description (if required)
 	*****************************************************************/
 
-	//cerr << "gPrintXMLSwitch " << gPrintXMLSwitch << endl;
-
 	if (gPrintXMLSwitch) {
-		//cerr << "masterfilename " << masterFilename << endl;
 		Description* 	D = C->getDescription(); assert(D);
 		ostream* 		xout = new ofstream(subst("$0.xml", masterFilename).c_str());
 
-		if(gNameProperty.size()) 		D->name(*gNameProperty.begin());
-		if(gAuthorProperty.size()) 		D->author(*gAuthorProperty.begin());
-		if(gCopyrightProperty.size()) 	D->copyright(*gCopyrightProperty.begin());
-		if(gLicenseProperty.size()) 	D->license(*gLicenseProperty.begin());
-		if(gVersionProperty.size()) 	D->version(*gVersionProperty.begin());
+        if(gMetaDataSet.count(tree("name"))>0)          D->name(tree2str(*(gMetaDataSet[tree("name")].begin())));
+        if(gMetaDataSet.count(tree("author"))>0)        D->author(tree2str(*(gMetaDataSet[tree("author")].begin())));
+        if(gMetaDataSet.count(tree("copyright"))>0)     D->copyright(tree2str(*(gMetaDataSet[tree("copyright")].begin())));
+        if(gMetaDataSet.count(tree("license"))>0)       D->license(tree2str(*(gMetaDataSet[tree("license")].begin())));
+        if(gMetaDataSet.count(tree("version"))>0)       D->version(tree2str(*(gMetaDataSet[tree("version")].begin())));
 
 		D->inputs(C->getClass()->inputs());
 		D->outputs(C->getClass()->outputs());
@@ -387,7 +410,7 @@ int main (int argc, char* argv[])
 
 	if (gArchFile != "") {
 		if ( (enrobage = open_arch_stream(gArchFile.c_str())) ) {
-
+            printheader(*dst);
 			C->getClass()->printLibrary(*dst);
 			C->getClass()->printIncludeFile(*dst);
 
@@ -404,6 +427,7 @@ int main (int argc, char* argv[])
 			return 1;
 		}
 	} else {
+        printheader(*dst);
 		C->getClass()->printLibrary(*dst);
 		C->getClass()->printIncludeFile(*dst);
 		C->getClass()->println(0,*dst);
