@@ -20,6 +20,7 @@
  ************************************************************************/
 
 #include    "symbol.hh"
+#include    "compatibility.hh"
 #include 	<iostream>
 
 using namespace std;
@@ -60,7 +61,7 @@ Symbol* Symbol::get(const string& str)
 
 Symbol* Symbol::get(const char* str)
 {
-    uint 			hsh  = calcHashKey(str);
+    unsigned int 			hsh  = calcHashKey(str);
     int 			bckt = hsh % kHashTableSize;
 	Symbol*			item = gSymbolTable[bckt];
 
@@ -78,7 +79,7 @@ Symbol* Symbol::get(const char* str)
 
 bool Symbol::isnew(const char* str)
 {
-    uint 			hsh  = calcHashKey(str);
+    unsigned int 			hsh  = calcHashKey(str);
     int 			bckt = hsh % kHashTableSize;
 	Symbol*			item = gSymbolTable[bckt];
 	
@@ -115,7 +116,7 @@ Symbol* Symbol::prefix (const char* str)
  * \return \p true if the name of the symbol and \p str are the same
  */
  
-bool Symbol::equiv (uint hash, const char *str) const
+bool Symbol::equiv (unsigned int hash, const char *str) const
 {
 	return (fHash == hash) && (strcmp(fName,str) == 0);
 }
@@ -128,9 +129,9 @@ bool Symbol::equiv (uint hash, const char *str) const
  * \return a 32-bits hash key
  */
 
-uint Symbol::calcHashKey (const char* str)
+unsigned int Symbol::calcHashKey (const char* str)
 {
-    uint h = 0;
+    unsigned int h = 0;
 
     while (*str) h = (h << 1) ^ (h >> 20) ^ (*str++);
     return h;
@@ -146,7 +147,7 @@ uint Symbol::calcHashKey (const char* str)
  * \param nxt a pointer to the next symbol in the hash table entry
  */
 
-Symbol::Symbol(const char* str, uint hsh, Symbol* nxt)
+Symbol::Symbol(const char* str, unsigned int hsh, Symbol* nxt)
 {
 	int len = strlen(str);
 	
